# Hardware Components
Provides Abstract Base Classes for basic hardware types.
Heavily inspired by and mostly compatible with 
[Mycroft's Mark 2](https://github.com/MycroftAI/mark-ii-hardware-testing)
hardware implementation.